==> jc-1.4.0.tar.gz: java/util/zip/ZipFile__24PartialInputStream.h <==
// class java.util.zip.ZipFile$PartialInputStream

// class file dependencies
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 128193db387c6801 java_util_zip_ZipFile__24PartialInputStream

// header file dependencies
// @dep_header java_io_InputStream

#include "java/io/InputStream.h"

#ifndef _JC_java_util_zip_ZipFile__24PartialInputStream_H_
#define _JC_java_util_zip_ZipFile__24PartialInputStream_H_

// Forward structure declarations
struct _jc_java_io_RandomAccessFile$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_util_zip_ZipFile__24PartialInputStream$sub_refs	_jc_java_util_zip_ZipFile__24PartialInputStream$sub_refs;
typedef struct _jc_java_util_zip_ZipFile__24PartialInputStream$sub_nonrefs	_jc_java_util_zip_ZipFile__24PartialInputStream$sub_nonrefs;
typedef struct _jc_java_util_zip_ZipFile__24PartialInputStream$refs	_jc_java_util_zip_ZipFile__24PartialInputStream$refs;
typedef struct _jc_java_util_zip_ZipFile__24PartialInputStream$nonrefs	_jc_java_util_zip_ZipFile__24PartialInputStream$nonrefs;
typedef struct _jc_java_util_zip_ZipFile__24PartialInputStream$object	_jc_java_util_zip_ZipFile__24PartialInputStream$object;

typedef const struct _jc_java_util_zip_ZipFile__24PartialInputStream$vmethods	_jc_java_util_zip_ZipFile__24PartialInputStream$vmethods;
typedef const struct _jc_java_util_zip_ZipFile__24PartialInputStream$vtable	_jc_java_util_zip_ZipFile__24PartialInputStream$vtable;
typedef const struct _jc_java_util_zip_ZipFile__24PartialInputStream$vtype	_jc_java_util_zip_ZipFile__24PartialInputStream$vtype;

// Constructors
extern void _jc_java_util_zip_ZipFile__24PartialInputStream$method$_init$2c52edb0412ee50d(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *, struct _jc_java_io_RandomAccessFile$object *, jlong, jlong);

// Virtual methods
extern jint _jc_java_util_zip_ZipFile__24PartialInputStream$method$available$81975cc608605037(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *);
extern jint _jc_java_util_zip_ZipFile__24PartialInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *);
extern jint _jc_java_util_zip_ZipFile__24PartialInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *, struct _jc_byte_array *, jint, jint);
extern jlong _jc_java_util_zip_ZipFile__24PartialInputStream$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *, jlong);

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_ZipFile__24PartialInputStream$method_info$available$81975cc608605037;
extern _jc_method _jc_java_util_zip_ZipFile__24PartialInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_util_zip_ZipFile__24PartialInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_util_zip_ZipFile__24PartialInputStream$method_info$skip$4e431136b5c4614a;

// Virtual methods structure
struct _jc_java_util_zip_ZipFile__24PartialInputStream$vmethods {
	jint	(*available$81975cc608605037)(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *, struct _jc_byte_array *, jint, jint);
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *, jlong);
};

// Vtable
struct _jc_java_util_zip_ZipFile__24PartialInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_util_zip_ZipFile__24PartialInputStream$vmethods	java_util_zip_ZipFile__24PartialInputStream;
};

// Vtype
struct _jc_java_util_zip_ZipFile__24PartialInputStream$vtype {
	_jc_type			type;
	_jc_java_util_zip_ZipFile__24PartialInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_ZipFile__24PartialInputStream$sub_refs {
	struct _jc_java_io_RandomAccessFile$object	*raf;
};

// Reference instance fields (object)
struct _jc_java_util_zip_ZipFile__24PartialInputStream$refs {
    _jc_java_util_zip_ZipFile__24PartialInputStream$sub_refs	java_util_zip_ZipFile__24PartialInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_ZipFile__24PartialInputStream$sub_nonrefs {
	jlong	filepos;
	jlong	end;
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_ZipFile__24PartialInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_util_zip_ZipFile__24PartialInputStream$sub_nonrefs	java_util_zip_ZipFile__24PartialInputStream;
};

// Object instance structure
struct _jc_java_util_zip_ZipFile__24PartialInputStream$object {
	_jc_java_util_zip_ZipFile__24PartialInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_ZipFile__24PartialInputStream$vtype	*vtype;
	_jc_java_util_zip_ZipFile__24PartialInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_ZipFile__24PartialInputStream$vtype _jc_java_util_zip_ZipFile__24PartialInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_ZipFile__24PartialInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_ZipFile__24PartialInputStream$class_object;

#endif	/* _JC_java_util_zip_ZipFile__24PartialInputStream_H_ */

==> jc-1.4.6.tar.gz: java/util/zip/ZipFile__24PartialInputStream.h <==
// class java.util.zip.ZipFile$PartialInputStream

// class file dependencies
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 128193db387c6801 java_util_zip_ZipFile__24PartialInputStream

// header file dependencies
// @dep_header java_io_InputStream

#include "java/io/InputStream.h"

#ifndef _JC_java_util_zip_ZipFile__24PartialInputStream_H_
#define _JC_java_util_zip_ZipFile__24PartialInputStream_H_

// Forward structure declarations
struct _jc_java_io_RandomAccessFile$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_util_zip_ZipFile__24PartialInputStream$sub_refs	_jc_java_util_zip_ZipFile__24PartialInputStream$sub_refs;
typedef struct _jc_java_util_zip_ZipFile__24PartialInputStream$sub_nonrefs	_jc_java_util_zip_ZipFile__24PartialInputStream$sub_nonrefs;
typedef struct _jc_java_util_zip_ZipFile__24PartialInputStream$refs	_jc_java_util_zip_ZipFile__24PartialInputStream$refs;
typedef struct _jc_java_util_zip_ZipFile__24PartialInputStream$nonrefs	_jc_java_util_zip_ZipFile__24PartialInputStream$nonrefs;
typedef struct _jc_java_util_zip_ZipFile__24PartialInputStream$object	_jc_java_util_zip_ZipFile__24PartialInputStream$object;

typedef const struct _jc_java_util_zip_ZipFile__24PartialInputStream$vmethods	_jc_java_util_zip_ZipFile__24PartialInputStream$vmethods;
typedef const struct _jc_java_util_zip_ZipFile__24PartialInputStream$vtable	_jc_java_util_zip_ZipFile__24PartialInputStream$vtable;
typedef const struct _jc_java_util_zip_ZipFile__24PartialInputStream$vtype	_jc_java_util_zip_ZipFile__24PartialInputStream$vtype;

// Constructors
extern void _jc_java_util_zip_ZipFile__24PartialInputStream$method$_init$2c52edb0412ee50d(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *, struct _jc_java_io_RandomAccessFile$object *, jlong, jlong) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_util_zip_ZipFile__24PartialInputStream$method$available$81975cc608605037(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_zip_ZipFile__24PartialInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_zip_ZipFile__24PartialInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern jlong _jc_java_util_zip_ZipFile__24PartialInputStream$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *, jlong) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_ZipFile__24PartialInputStream$method_info$available$81975cc608605037;
extern _jc_method _jc_java_util_zip_ZipFile__24PartialInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_util_zip_ZipFile__24PartialInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_util_zip_ZipFile__24PartialInputStream$method_info$skip$4e431136b5c4614a;

// Virtual methods structure
struct _jc_java_util_zip_ZipFile__24PartialInputStream$vmethods {
	jint	(*available$81975cc608605037)(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_java_util_zip_ZipFile__24PartialInputStream$object *, jlong) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_zip_ZipFile__24PartialInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_util_zip_ZipFile__24PartialInputStream$vmethods	java_util_zip_ZipFile__24PartialInputStream;
};

// Vtype
struct _jc_java_util_zip_ZipFile__24PartialInputStream$vtype {
	_jc_type			type;
	_jc_java_util_zip_ZipFile__24PartialInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_ZipFile__24PartialInputStream$sub_refs {
	struct _jc_java_io_RandomAccessFile$object	*raf;
};

// Reference instance fields (object)
struct _jc_java_util_zip_ZipFile__24PartialInputStream$refs {
    _jc_java_util_zip_ZipFile__24PartialInputStream$sub_refs	java_util_zip_ZipFile__24PartialInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_ZipFile__24PartialInputStream$sub_nonrefs {
	jlong	filepos;
	jlong	end;
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_ZipFile__24PartialInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_util_zip_ZipFile__24PartialInputStream$sub_nonrefs	java_util_zip_ZipFile__24PartialInputStream;
};

// Object instance structure
struct _jc_java_util_zip_ZipFile__24PartialInputStream$object {
	_jc_java_util_zip_ZipFile__24PartialInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_ZipFile__24PartialInputStream$vtype	*vtype;
	_jc_java_util_zip_ZipFile__24PartialInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_ZipFile__24PartialInputStream$vtype _jc_java_util_zip_ZipFile__24PartialInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_ZipFile__24PartialInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_ZipFile__24PartialInputStream$class_object;

#endif	/* _JC_java_util_zip_ZipFile__24PartialInputStream_H_ */
